@@ -152,11 +152,11 @@ sub parse_am_file
 	    };
 
 	} elsif ($continued_line) {
-	    $continued_line = /\\$/;
+	    $continued_line = /\\\s*$/;
 	    if ($in_rule) {
 		if ($rules{$current_rule}{actions} eq "") {
 		    # Strip trailing backslash from rule deps
-		    s/\\w*$//;
+		    s/\\\s*$//;
 		    $rules{$current_rule}{dependencies} .= $_;
 		} else {
 		    $rules{$current_rule}{actions} .= $_;
@@ -165,7 +165,7 @@ sub parse_am_file
 	    elsif ($current_macro) {
 		# Chop newline and backslash if this line is
 		# continued.  ensure trailing whitespace exists.
-		s/\\w*$//;
+		s/\\\s*$//;
 		$macros{$current_macro}{contents} .= $_;
 	    }
 	    else {
@@ -182,7 +182,7 @@ sub parse_am_file
 
 	    my $value = $2;
 	    if (defined ($value)) {
-		$value =~ s/\\w*$//;
+		$value =~ s/\\\s*$//;
 	    } else {
 		$value = "";
 	    };
@@ -192,7 +192,7 @@ sub parse_am_file
 			   used         => 0 };
 	    
 	    &debug ("$filename:$.: Found rule '$1'");
-	    $continued_line = /\\$/;
+	    $continued_line = /\\\s*$/;
 
 	} elsif (($is_ok_macro = /$MACRO_PATTERN/o)
 		 || /$BOGUS_MACRO_PATTERN/o) {
@@ -227,7 +227,7 @@ sub parse_am_file
 
 	    &debug ("$filename:$.: Found macro '$1'");
 	    
-	    $continued_line = /\\$/;
+	    $continued_line = /\\\s*$/;
 
 	} elsif (/$INCLUDE_PATTERN/o) {
 	    # Include
@@ -249,7 +249,7 @@ sub parse_am_file
 	    }
 
 	    $current_macro = "";
-	    $continued_line = /\\$/;
+	    $continued_line = /\\\s*$/;
 	    
 	    if ($in_rule) {
 		$rules{$current_rule}{actions} .= $_;
@@ -662,7 +662,7 @@ sub analyze_macro_style
 	my $line_copy = &expand_tabs ($line);
 	my $bs = $bs_column;
 	
-	if ($line_copy =~ /\\$/) {
+	if ($line_copy =~ /\\\s*$/) {
 	    # first get the column of the backslash
 	    $bs = rindex $line_copy, '\\';
 	};
@@ -674,7 +674,7 @@ sub analyze_macro_style
 	    $line =~ /^(\s+)\S+/;
 	    $leading_space = $1;
 	};
-	$line_copy =~ s/\\$//;
+	$line_copy =~ s/\\\s*$//;
 	
 	my @items = split /\s+/, &trim ($line_copy);
 	
@@ -698,7 +698,7 @@ sub analyze_macro_style
 	};
 	
 	$first_line = 0;
-    } while ($line =~ /\\$/);
+    } while ($line =~ /\\\s*$/);
     
     &debug ("Macro: $macro_name, " .
 	    "bs_column = $bs_column, items_per_line = $items_per_line, ".
@@ -850,7 +850,7 @@ sub macro_prepend_text
 	$first_line =~ /$MACRO_PATTERN/;
 	my $leading_text = $3;
 	$text .= " " . $leading_text;
-	$text =~ s/\\$//;
+	$text =~ s/\\\s*$//;
 	$first_line = substr $first_line, 0, -length ($leading_text) - 1;
 
 	my @lines = &format_macro ($first_line, $text, $macro_style, 
@@ -944,7 +944,7 @@ sub macro_remove
 	    &debug ("Removing macro $macro_name at line $line");
 	    
 	    my $count = 1;
-	    while (@{$makefile->{lines}}[$line + $count - 2] =~ /\\$/) {
+	    while (@{$makefile->{lines}}[$line + $count - 2] =~ /\\\s*$/) {
 		$count++;
 	    };
 	    
@@ -959,12 +959,15 @@ sub macro_rewrite
 {
     # Rewrites the macro with the new text, but trying to accomodate to the
     # previous style
-    my ($makefile, $macro_name, $text) = @_;
+    my ($makefile, $macro_name, $text, $hint_near) = @_;
 
     my $macro = $makefile->{macros}{$macro_name};
     if (!defined ($macro)) {
+    	if ($hint_near eq "") {
+	    $hint_near = &last_macro ($makefile);
+	}
 	# If the macro doesn't exist create it
-	&macro_create ($makefile, $macro_name, $text, &last_macro ($makefile));
+	&macro_create ($makefile, $macro_name, $text, $hint_near);
 
     } elsif ($macro->{atline} > 0) {
 	my ($last_line_num, $macro_style) =
@@ -1020,7 +1023,7 @@ sub macro_remove_text
 	    } else {
 		# else, just remove the text, the trailing bs and reformat the line
 		$line =~ s/$remove_text\s//;
-		$line =~ s/\\$//;
+		$line =~ s/\\\s*$//;
 		if ($line !~ /^\s+/ && $line_num > $macro->{atline}) {
 		    $line = $macro_style->{leading_space} . $line;
 		};
@@ -1071,7 +1074,7 @@ sub rule_remove
 	    my $maxcount = scalar @{$makefile->{lines}} - $line;
 	    # count dependency lines
 	    while ($count < $maxcount && 
-		   @{$makefile->{lines}}[$line + $count - 2] =~ /\\$/) {
+		   @{$makefile->{lines}}[$line + $count - 2] =~ /\\\s*$/) {
 		$count++;
 	    };
 	    # count action lines
@@ -1223,7 +1226,7 @@ sub analyze_text ($$$)
 
 	# sample data
 	$widths[$line_length]++;
-	$backslashed = 1 if $expanded_line =~ m/\\$/;
+	$backslashed = 1 if $expanded_line =~ m/\\\s*$/;
 	$expanded_line = chop_backslash $expanded_line;
 	if ($line_number != 0 && $line_number != @lines - 1) {
 	    $expanded_line =~ m/^(\s*)\S.*\S(\s*)$/;
@@ -1419,8 +1422,7 @@ sub edit_config_files ($$$)
 					 $operand, $style);
 
     } elsif ($action eq "remove") {
-	# FIXME
-
+	$new_config_files =~ s/\Q$operand\E\s*//g;
     };
 
     # save result string
