@@ -19,6 +19,7 @@
  * Boston, MA 02111-1307, USA.
  *
  * Author: JP Rosevear
+ * Author: Naba Kumar
  */
 
 #ifdef HAVE_CONFIG_H
@@ -43,6 +44,7 @@
 #include "gbf-am-project.h"
 #include "gbf-am-build.h"
 #include "gbf-am-config.h"
+#include "gbf-am-properties.h"
 
 #define ENABLE_DEBUG
 
@@ -71,7 +73,7 @@ typedef enum {
 typedef struct {
 	GbfAmProject       *project;
 	GbfAmProjectOpType  type;
-	GbfBuildType        build_type;
+	gchar 		   *build_id;
 } GbfAmProjectOp;
 
 
@@ -303,10 +305,11 @@ queue_check (GbfAmProject *project)
 			gchar *project_root = uri_to_path (project->project_root_uri);
 						
 			/* FIXME: gbf_build_run can be simpler */
-			gbf_build_run (project, op->build_type,
+			gbf_build_run (project, op->build_id,
 				       project_root,
 				       project->callbacks);
 
+			g_free (op->build_id);
 			g_free (project_root);
 			
 			break;
@@ -664,6 +667,156 @@ xml_write_add_target (GbfAmProject *project,
 	return TRUE;
 }
 
+typedef struct {
+	GbfAmConfigMapping *old_config;
+	xmlDocPtr doc;
+	xmlNodePtr curr_xml_node;
+} GbfXmlWriteData;
+
+static void
+xml_write_set_item_config_cb (const gchar *param, GbfAmConfigValue *value,
+			      gpointer user_data)
+{
+	xmlNodePtr param_node;
+	GbfXmlWriteData *data = (GbfXmlWriteData*)user_data;
+	
+	if (value->type == GBF_AM_TYPE_STRING) {
+		GbfAmConfigValue *old_value;
+		const gchar *old_str = "", *new_str = "";
+		
+		new_str = gbf_am_config_value_get_string (value);
+		if (new_str == NULL)
+			new_str = "";
+		
+		old_value = gbf_am_config_mapping_lookup (data->old_config, param);
+		if (old_value) {
+			old_str = gbf_am_config_value_get_string (old_value);
+			if (old_str == NULL)
+				old_str = "";
+		}
+		if (strcmp (new_str, old_str) != 0)
+		{
+			param_node = xmlNewDocNode (data->doc, NULL,
+						    "item", NULL);
+			xmlSetProp (param_node, "name", param);
+			xmlSetProp (param_node, "value", new_str);
+			xmlAddChild (data->curr_xml_node, param_node);
+		}
+	}
+}
+
+static void
+xml_write_set_param_config_cb (const gchar *param, GbfAmConfigValue *value,
+			       gpointer user_data)
+{
+	xmlNodePtr param_node;
+	GbfXmlWriteData *data = (GbfXmlWriteData*)user_data;
+	
+	if (value->type == GBF_AM_TYPE_STRING) {
+		GbfAmConfigValue *old_value;
+		const gchar *old_str = "", *new_str = "";
+		
+		new_str = gbf_am_config_value_get_string (value);
+		if (new_str == NULL)
+			new_str = "";
+		
+		old_value = gbf_am_config_mapping_lookup (data->old_config, param);
+		if (old_value) {
+			old_str = gbf_am_config_value_get_string (old_value);
+			if (old_str == NULL)
+				old_str = "";
+		}
+		if (strcmp (new_str, old_str) != 0)
+		{
+			param_node = xmlNewDocNode (data->doc, NULL,
+						    "param", NULL);
+			xmlSetProp (param_node, "name", param);
+			xmlSetProp (param_node, "value", new_str);
+			xmlAddChild (data->curr_xml_node, param_node);
+		}
+	} else if (value->type == GBF_AM_TYPE_LIST) {
+		param_node = xmlNewDocNode (data->doc, NULL,
+					    "param", NULL);
+		xmlSetProp (param_node, "name", param);
+		/* FIXME */
+	} else if (value->type == GBF_AM_TYPE_MAPPING) {
+		
+		GbfXmlWriteData write_data;
+		GbfAmConfigValue *old_value;
+		GbfAmConfigMapping *new_mapping, *old_mapping;
+		
+		new_mapping = gbf_am_config_value_get_mapping (value);
+		old_value = gbf_am_config_mapping_lookup (data->old_config, param);
+		old_mapping = gbf_am_config_value_get_mapping (old_value);
+		
+		param_node = xmlNewDocNode (data->doc, NULL, "param", NULL);
+		
+		xmlSetProp (param_node, "name", param);
+		
+		write_data.doc = data->doc;
+		write_data.curr_xml_node = param_node;
+		write_data.old_config = old_mapping;
+		
+		gbf_am_config_mapping_foreach (new_mapping,
+					       xml_write_set_item_config_cb,
+					       &write_data);
+		if (param_node->children)
+			xmlAddChild (data->curr_xml_node, param_node);
+		else
+			xmlFreeNode (param_node);
+	} else {
+		g_warning ("Should not be here");
+	}
+}
+
+static gboolean 
+xml_write_set_config (GbfAmProject       *project,
+		      xmlDocPtr           doc,
+		      GNode              *g_node,
+		      GbfAmConfigMapping *new_config)
+{
+	xmlNodePtr cur, config;
+	GbfXmlWriteData user_data;
+	
+	cur = xmlNewDocNode (doc, NULL, "set", NULL);
+	xmlSetProp (cur, "type", "config");
+	xmlAddChild (doc->children, cur);
+
+	if (g_node)
+		cur = xml_write_location_recursive (project, doc, cur, g_node);
+	
+	config = xmlNewDocNode (doc, NULL, "config", NULL);
+	xmlAddChild (cur, config);
+	
+	user_data.doc = doc;
+	user_data.curr_xml_node = config;
+	user_data.old_config = GBF_AM_NODE (g_node)->config;
+	
+	gbf_am_config_mapping_foreach (new_config,
+				       xml_write_set_param_config_cb,
+				       &user_data);
+	if (config->children)
+		return TRUE;
+	else
+		return FALSE;
+}
+
+static gboolean
+xml_write_remove_target (GbfAmProject *project,
+			 xmlDocPtr     doc,
+			 GNode        *g_node)
+{
+	xmlNodePtr cur;
+
+	cur = xmlNewDocNode (doc, NULL, "remove", NULL);
+	xmlSetProp (cur, "type", "target");
+	xmlAddChild (doc->children, cur);
+	
+	cur = xml_write_location_recursive (project, doc, cur, g_node);
+	
+	return (cur != NULL);
+}
+
 static gboolean 
 xml_write_add_group (GbfAmProject *project,
 		     xmlDocPtr     doc,
@@ -690,6 +843,22 @@ xml_write_add_group (GbfAmProject *project,
 	return TRUE;
 }
 
+static gboolean
+xml_write_remove_group (GbfAmProject *project,
+			 xmlDocPtr     doc,
+			 GNode        *g_node)
+{
+	xmlNodePtr cur;
+
+	cur = xmlNewDocNode (doc, NULL, "remove", NULL);
+	xmlSetProp (cur, "type", "group");
+	xmlAddChild (doc->children, cur);
+	
+	cur = xml_write_location_recursive (project, doc, cur, g_node);
+	
+	return (cur != NULL);
+}
+
 static xmlDocPtr
 xml_new_change_doc (GbfAmProject *project)
 {
@@ -2268,6 +2437,177 @@ project_data_init (GbfAmProject *project)
 	project->sources = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 }
 
+GbfAmConfigMapping *
+gbf_am_project_get_config (GbfAmProject *project, GError **error)
+{
+	g_return_val_if_fail (GBF_IS_AM_PROJECT (project), NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+	
+	return gbf_am_config_mapping_copy (project->project_config);
+}
+
+GbfAmConfigMapping *
+gbf_am_project_get_group_config (GbfAmProject *project, const gchar *group_id,
+				 GError **error)
+{
+	GbfAmNode *node;
+	GNode *g_node;
+	
+	g_return_val_if_fail (GBF_IS_AM_PROJECT (project), NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+	
+	g_node = g_hash_table_lookup (project->groups, group_id);
+	if (g_node == NULL) {
+		error_set (error, GBF_PROJECT_ERROR_DOESNT_EXIST,
+			   _("Group doesn't exist"));
+		return NULL;
+	}
+	node = GBF_AM_NODE (g_node);
+	return gbf_am_config_mapping_copy (node->config);
+}
+
+GbfAmConfigMapping *
+gbf_am_project_get_target_config (GbfAmProject *project, const gchar *target_id,
+				  GError **error)
+{
+	GbfAmNode *node;
+	GNode *g_node;
+	
+	g_return_val_if_fail (GBF_IS_AM_PROJECT (project), NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+	
+	g_node = g_hash_table_lookup (project->targets, target_id);
+	if (g_node == NULL) {
+		error_set (error, GBF_PROJECT_ERROR_DOESNT_EXIST,
+			   _("Target doesn't exist"));
+		return NULL;
+	}
+	node = GBF_AM_NODE (g_node);
+	return gbf_am_config_mapping_copy (node->config);
+}
+
+void
+gbf_am_project_set_config (GbfAmProject *project,
+			   GbfAmConfigMapping *new_config, GError **error)
+{
+	xmlDocPtr doc;
+	GSList *change_set = NULL;
+	
+	g_return_if_fail (GBF_IS_AM_PROJECT (project));
+	g_return_if_fail (new_config != NULL);
+	g_return_if_fail (error == NULL || *error == NULL);
+	
+	/* Create the update xml */
+	doc = xml_new_change_doc (project);
+	
+	if (!xml_write_set_config (project, doc, NULL, new_config)) {
+		xmlFreeDoc (doc);
+		return;
+	}
+
+	DEBUG ({
+		xmlSetDocCompressMode (doc, 0);
+		xmlSaveFile ("/tmp/set-config.xml", doc);
+	});
+
+	/* Update the project */
+	if (!project_update (project, doc, &change_set, error)) {
+		error_set (error, GBF_PROJECT_ERROR_PROJECT_MALFORMED,
+			   _("Unable to update project"));
+		xmlFreeDoc (doc);
+		return;
+	}
+	xmlFreeDoc (doc);
+	change_set_destroy (change_set);
+}
+
+void
+gbf_am_project_set_group_config (GbfAmProject *project, const gchar *group_id,
+				 GbfAmConfigMapping *new_config, GError **error)
+{
+	GbfAmNode *node;
+	xmlDocPtr doc;
+	GNode *g_node;
+	GSList *change_set = NULL;
+	
+	g_return_if_fail (GBF_IS_AM_PROJECT (project));
+	g_return_if_fail (new_config != NULL);
+	g_return_if_fail (error == NULL || *error == NULL);
+	
+	g_node = g_hash_table_lookup (project->groups, group_id);
+	if (g_node == NULL) {
+		error_set (error, GBF_PROJECT_ERROR_DOESNT_EXIST,
+			   _("Group doesn't exist"));
+		return;
+	}
+	node = GBF_AM_NODE (g_node);
+	
+	/* Create the update xml */
+	doc = xml_new_change_doc (project);
+	if (!xml_write_set_config (project, doc, g_node, new_config)) {
+		xmlFreeDoc (doc);
+		return;
+	}
+
+	DEBUG ({
+		xmlSetDocCompressMode (doc, 0);
+		xmlSaveFile ("/tmp/set-config.xml", doc);
+	});
+	
+	/* Update the project */
+	if (!project_update (project, doc, &change_set, error)) {
+		error_set (error, GBF_PROJECT_ERROR_PROJECT_MALFORMED,
+			   _("Unable to update project"));
+		xmlFreeDoc (doc);
+		return;
+	}
+	xmlFreeDoc (doc);
+	change_set_destroy (change_set);
+}
+
+void
+gbf_am_project_set_target_config (GbfAmProject *project,
+				  const gchar *target_id,
+				  GbfAmConfigMapping *new_config,
+				  GError **error)
+{
+	xmlDocPtr doc;
+	GNode *g_node;
+	GSList *change_set = NULL;
+	
+	g_return_if_fail (GBF_IS_AM_PROJECT (project));
+	g_return_if_fail (new_config != NULL);
+	g_return_if_fail (error == NULL || *error == NULL);
+	
+	g_node = g_hash_table_lookup (project->targets, target_id);
+	if (g_node == NULL) {
+		error_set (error, GBF_PROJECT_ERROR_DOESNT_EXIST,
+			   _("Target doesn't exist"));
+	}
+	
+	/* Create the update xml */
+	doc = xml_new_change_doc (project);
+	if (!xml_write_set_config (project, doc, g_node, new_config)) {
+		xmlFreeDoc (doc);
+		return;
+	}
+
+	DEBUG ({
+		xmlSetDocCompressMode (doc, 0);
+		xmlSaveFile ("/tmp/set-config.xml", doc);
+	});
+
+	/* Update the project */
+	if (!project_update (project, doc, &change_set, error)) {
+		error_set (error, GBF_PROJECT_ERROR_PROJECT_MALFORMED,
+			   _("Unable to update project"));
+		xmlFreeDoc (doc);
+		return;
+	}
+	xmlFreeDoc (doc);
+	change_set_destroy (change_set);
+}
+
 /*
  * GbfProjectIface methods ------------------------------------------
  */
@@ -2330,7 +2670,7 @@ impl_load (GbfProject  *_project,
 
 static void
 impl_build (GbfProject  *_project,
-	    GbfBuildType type,
+	    const gchar *id,
 	    GError     **error)
 {
 	GbfAmProject *project;
@@ -2342,7 +2682,25 @@ impl_build (GbfProject  *_project,
 	op = g_new0 (GbfAmProjectOp, 1);
 	op->project = project;
 	op->type = BUILD;
-	op->build_type = type;
+
+	op->build_id = g_strdup (id);
+	queue_push_op (project, op);
+}
+
+static void
+impl_clean (GbfProject *_project,
+	    GError    **error)
+{
+	GbfAmProject *project;
+	GbfAmProjectOp *op;
+
+	g_return_if_fail (GBF_IS_AM_PROJECT (_project));
+
+	project = GBF_AM_PROJECT (_project);
+	op = g_new0 (GbfAmProjectOp, 1);
+	op->project = project;
+	op->type = BUILD;
+	op->build_id = g_strdup (GBF_AM_BUILD_ID_CLEAN);
 
 	queue_push_op (project, op);
 }
@@ -2385,6 +2743,90 @@ impl_probe (GbfProject  *_project,
 	return retval;
 }
 
+static void
+impl_refresh (GbfProject *_project,
+	      GError    **error)
+{
+	GbfAmProject *project;
+
+	g_return_if_fail (GBF_IS_AM_PROJECT (_project));
+
+	project = GBF_AM_PROJECT (_project);
+
+	if (project_reload (project, error))
+		g_signal_emit_by_name (G_OBJECT (project), "project-updated");
+}
+
+
+static void
+foreach_build_target (gpointer key, gpointer value, gpointer data)
+{
+	GList **targets = data;
+	GbfAmNode *node;
+	GbfBuildTarget *target;
+
+	node = GBF_AM_NODE ((GNode *)value);
+
+	if ( 0 == strcmp (node->detail, "program") ||
+	     0 == strcmp (node->detail, "static_lib") ||
+	     0 == strcmp (node->detail, "shared_lib") ) {
+		target = g_new0 (GbfBuildTarget, 1);
+		target->id = g_strdup_printf ("USER:%s", (gchar *) key);
+		target->label = g_strdup (node->name);
+		target->description = g_strdup_printf (_("Build specific target: %s"), node->name);
+
+		*targets = g_list_append (*targets, target);
+	}
+}
+
+
+static GList *
+impl_get_build_targets (GbfProject *_project,
+			GError    **error)
+{
+	GbfAmProject *project;
+	GbfBuildTarget *target;
+	GList *targets = NULL;
+
+	g_return_val_if_fail (GBF_IS_AM_PROJECT (_project), NULL);
+
+	project = GBF_AM_PROJECT (_project);
+
+	/* FIXME: these targets should be gotten from the Makefile.am files */
+	/* "autogen" */
+	target = g_new0 (GbfBuildTarget, 1);
+	target->id = g_strdup (GBF_AM_BUILD_ID_AUTOGEN);
+	target->label = g_strdup (_("Generate"));
+	target->description = g_strdup (_("Generate Makefile"));
+	targets = g_list_append (targets, target);
+
+	/* "configure" */
+	target = g_new0 (GbfBuildTarget, 1);
+	target->id = g_strdup (GBF_AM_BUILD_ID_CONFIGURE);
+	target->label = g_strdup (_("Configure"));
+	target->description = g_strdup (_("Configure the project"));
+	targets = g_list_append (targets, target);
+
+	/* "make all" */
+	target = g_new0 (GbfBuildTarget, 1);
+	target->id = g_strdup (GBF_AM_BUILD_ID_ALL);
+	target->label = g_strdup (_("All"));
+	target->description = g_strdup (_("Build the entire project"));
+	targets = g_list_append (targets, target);
+
+	/* "make install" */
+	target = g_new0 (GbfBuildTarget, 1);
+	target->id = g_strdup (GBF_AM_BUILD_ID_INSTALL);
+	target->label = g_strdup (_("Install"));
+	target->description = g_strdup (_("Build the entire project and install it"));
+	targets = g_list_append (targets, target);
+
+	/* other build targets */
+	g_hash_table_foreach (project->targets, foreach_build_target, &targets);
+
+	return targets;
+}
+
 static void
 impl_add_build_callback (GbfProject      *_project,
 			 GbfBuildCallback callback,
@@ -2477,6 +2919,30 @@ impl_get_group (GbfProject  *_project,
 	return group;
 }
 
+static void
+foreach_group (gpointer key, gpointer value, gpointer data)
+{
+	GList **groups = data;
+
+	*groups = g_list_prepend (*groups, g_strdup (key));
+}
+
+
+static GList *
+impl_get_all_groups (GbfProject *_project,
+		     GError    **error)
+{
+	GbfAmProject *project;
+	GList *groups = NULL;
+
+	g_return_val_if_fail (GBF_IS_AM_PROJECT (_project), NULL);
+
+	project = GBF_AM_PROJECT (_project);
+	g_hash_table_foreach (project->groups, foreach_group, &groups);
+
+	return groups;
+}
+
 static GtkWidget *
 impl_configure_new_group (GbfProject *_project,
 			  GError    **error)
@@ -2491,9 +2957,19 @@ impl_configure_group (GbfProject  *_project,
 		      const gchar *id,
 		      GError     **error)
 {
-	UNIMPLEMENTED;
-
-	return NULL;
+	GtkWidget *wid = NULL;
+	GError *err = NULL;
+	
+	g_return_val_if_fail (GBF_IS_PROJECT (_project), NULL);
+	g_return_val_if_fail (id != NULL, NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+	
+	wid = gbf_am_properties_get_group_widget (GBF_AM_PROJECT (_project),
+						  id, &err);
+	if (err) {
+		g_propagate_error (error, err);
+	}
+	return wid;
 }
 
 static gchar * 
@@ -2577,7 +3053,44 @@ impl_remove_group (GbfProject  *_project,
 		   const gchar *id,
 		   GError     **error)
 {
-	UNIMPLEMENTED;
+	GbfAmProject *project;
+	GNode *g_node;
+	xmlDocPtr doc;
+	GSList *change_set = NULL;
+	
+	g_return_if_fail (GBF_IS_AM_PROJECT (_project));
+
+	project = GBF_AM_PROJECT (_project);
+	
+	/* Find the target */
+	g_node = g_hash_table_lookup (project->groups, id);
+	if (g_node == NULL) {
+		error_set (error, GBF_PROJECT_ERROR_DOESNT_EXIST,
+			   _("Group doesn't exist"));
+		return;
+	}
+
+	/* Create the update xml */
+	doc = xml_new_change_doc (project);
+	if (!xml_write_remove_group (project, doc, g_node)) {
+		error_set (error, GBF_PROJECT_ERROR_DOESNT_EXIST,
+			   _("Group coudn't be removed"));
+		xmlFreeDoc (doc);
+		return;
+	}
+
+	DEBUG ({
+		xmlSetDocCompressMode (doc, 0);
+		xmlSaveFile ("/tmp/remove-group.xml", doc);
+	});
+
+	/* Update the project */
+	if (!project_update (project, doc, &change_set, error)) {
+		error_set (error, GBF_PROJECT_ERROR_PROJECT_MALFORMED,
+			   _("Unable to update project"));
+	}
+	xmlFreeDoc (doc);
+	change_set_destroy (change_set);
 }
 
 static GbfProjectTarget * 
@@ -2635,7 +3148,6 @@ foreach_target (gpointer key, gpointer value, gpointer data)
 	*targets = g_list_prepend (*targets, g_strdup (key));
 }
 
-
 static GList *
 impl_get_all_targets (GbfProject *_project,
 		      GError    **error)
@@ -2665,9 +3177,19 @@ impl_configure_target (GbfProject  *_project,
 		       const gchar *id,
 		       GError     **error)
 {
-	UNIMPLEMENTED;
-
-	return NULL;
+	GtkWidget *wid = NULL;
+	GError *err = NULL;
+	
+	g_return_val_if_fail (GBF_IS_PROJECT (_project), NULL);
+	g_return_val_if_fail (id != NULL, NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+	
+	wid = gbf_am_properties_get_target_widget (GBF_AM_PROJECT (_project),
+						   id, &err);
+	if (err) {
+		g_propagate_error (error, err);
+	}
+	return wid;
 }
 
 static char * 
@@ -2754,7 +3276,44 @@ impl_remove_target (GbfProject  *_project,
 		    const gchar *id,
 		    GError     **error)
 {
-	UNIMPLEMENTED;
+	GbfAmProject *project;
+	GNode *g_node;
+	xmlDocPtr doc;
+	GSList *change_set = NULL;
+	
+	g_return_if_fail (GBF_IS_AM_PROJECT (_project));
+
+	project = GBF_AM_PROJECT (_project);
+	
+	/* Find the target */
+	g_node = g_hash_table_lookup (project->targets, id);
+	if (g_node == NULL) {
+		error_set (error, GBF_PROJECT_ERROR_DOESNT_EXIST,
+			   _("Target doesn't exist"));
+		return;
+	}
+
+	/* Create the update xml */
+	doc = xml_new_change_doc (project);
+	if (!xml_write_remove_target (project, doc, g_node)) {
+		error_set (error, GBF_PROJECT_ERROR_DOESNT_EXIST,
+			   _("Target coudn't be removed"));
+		xmlFreeDoc (doc);
+		return;
+	}
+
+	DEBUG ({
+		xmlSetDocCompressMode (doc, 0);
+		xmlSaveFile ("/tmp/remove-target.xml", doc);
+	});
+
+	/* Update the project */
+	if (!project_update (project, doc, &change_set, error)) {
+		error_set (error, GBF_PROJECT_ERROR_PROJECT_MALFORMED,
+			   _("Unable to update project"));
+	}
+	xmlFreeDoc (doc);
+	change_set_destroy (change_set);
 }
 
 static const gchar * 
@@ -3044,6 +3603,22 @@ impl_remove_source (GbfProject  *_project,
 	xmlFreeDoc (doc);
 }
 
+static GtkWidget *
+impl_configure (GbfProject *_project, GError **error)
+{
+	GtkWidget *wid = NULL;
+	GError *err = NULL;
+	
+	g_return_val_if_fail (GBF_IS_PROJECT (_project), NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+	
+	wid = gbf_am_properties_get_widget (GBF_AM_PROJECT (_project), &err);
+	if (err) {
+		g_propagate_error (error, err);
+	}
+	return wid;
+}
+
 static void
 gbf_am_project_class_init (GbfAmProjectClass *klass)
 {
@@ -3059,14 +3634,18 @@ gbf_am_project_class_init (GbfAmProjectClass *klass)
 
 	project_class->load = impl_load;
 	project_class->build = impl_build;
+	project_class->clean = impl_clean;
 	project_class->probe = impl_probe;
+	project_class->refresh = impl_refresh;
 
+	project_class->get_build_targets = impl_get_build_targets;
 	project_class->add_build_callback = impl_add_build_callback;
 	project_class->remove_build_callback = impl_remove_build_callback;
 
 	project_class->add_group = impl_add_group;
 	project_class->remove_group = impl_remove_group;
 	project_class->get_group = impl_get_group;
+	project_class->get_all_groups = impl_get_all_groups;
 	project_class->configure_group = impl_configure_group;
 	project_class->configure_new_group = impl_configure_new_group;
 
@@ -3084,6 +3663,7 @@ gbf_am_project_class_init (GbfAmProjectClass *klass)
 	project_class->configure_source = impl_configure_source;
 	project_class->configure_new_source = impl_configure_new_source;
 
+	project_class->configure = impl_configure;
 	project_class->name_for_type = impl_name_for_type;
 	project_class->mimetype_for_type = impl_mimetype_for_type;
 	project_class->get_types = impl_get_types;
@@ -3114,6 +3694,12 @@ gbf_am_project_instance_init (GbfAmProject *project)
 	
 	/* initialize build callbacks */
 	project->callbacks = NULL;
+
+	/* FIXME: those path should be configurable */
+	project->make_command = g_strdup ("/usr/bin/make");
+	project->configure_command = g_strdup ("./configure");
+	project->autogen_command = g_strdup ("./autogen.sh");
+	project->install_prefix = g_strdup ("/gnome");
 }
 
 static void
@@ -3136,7 +3722,11 @@ gbf_am_project_dispose (GObject *object)
 
 	/* disconnect callbacks */
 	callbacks_destroy (project);
-
+	g_free (project->make_command);
+	g_free (project->configure_command);
+	g_free (project->autogen_command);
+	g_free (project->install_prefix);
+	
 	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (object));
 }
 
