@@ -50,6 +50,7 @@ struct _GbfProjectViewPrivate {
 enum {
 	URI_ACTIVATED,
 	TARGET_SELECTED,
+	GROUP_SELECTED,
 	LAST_SIGNAL
 };
 
@@ -104,6 +105,12 @@ row_activated (GtkTreeView       *tree_view,
 			       data->id);
 	}
 	
+	if (data->type == GBF_TREE_NODE_GROUP) {
+		g_signal_emit (G_OBJECT (tree_view),
+			       signals [GROUP_SELECTED], 0,
+			       data->id);
+	}
+	
 	gbf_tree_data_free (data);
 }
 
@@ -258,6 +265,15 @@ gbf_project_view_class_init (GbfProjectViewClass *klass)
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__STRING,
 			      G_TYPE_NONE, 1, G_TYPE_STRING);
+	signals [GROUP_SELECTED] = 
+		g_signal_new ("group_selected",
+			      GBF_TYPE_PROJECT_VIEW,
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GbfProjectViewClass,
+					       group_selected),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__STRING,
+			      G_TYPE_NONE, 1, G_TYPE_STRING);
 }
 
 static void 
